@@ -1,4 +1,4 @@
-"""CrowdStrike Falcon Firewall Policy API interface class
+"""CrowdStrike Falcon Firewall Policy API interface class.
 
  _______                        __ _______ __        __ __
 |   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
@@ -43,7 +43,7 @@ from ._endpoint._firewall_policies import _firewall_policies_endpoints as Endpoi
 
 
 class FirewallPolicies(ServiceClass):
-    """The only requirement to instantiate an instance of this class is one of the following:
+    """The only requirement to instantiate an instance of this class is one of the following.
 
     - a valid client_id and client_secret provided as keywords.
     - a credential dictionary with client_id and client_secret containing valid API credentials
@@ -54,10 +54,12 @@ class FirewallPolicies(ServiceClass):
     - a previously-authenticated instance of the authentication service class (oauth2.py)
     - a valid token provided by the authentication service class (OAuth2.token())
     """
+
     @force_default(defaults=["parameters"], default_types=["dict"])
     def query_combined_policy_members(self: object, parameters: dict = None, **kwargs) -> dict:
-        """Search for members of a Firewall Policy in your environment by providing an FQL filter
-        and paging details. Returns a set of host details which match the filter criteria.
+        """Search for members of a Firewall Policy in your environment by providing an FQL filter and paging details.
+
+        Returns a set of host details which match the filter criteria.
 
         Keyword arguments:
         id -- The ID of the Firewall Policy to search for members of
@@ -88,9 +90,9 @@ class FirewallPolicies(ServiceClass):
 
     @force_default(defaults=["parameters"], default_types=["dict"])
     def query_combined_policies(self: object, parameters: dict = None, **kwargs) -> dict:
-        """Search for Firewall Policies in your environment by providing
-        an FQL filter and paging details. Returns a set of Firewall Policies
-        which match the filter criteria.
+        """Search for Firewall Policies in your environment by providing an FQL filter and paging details.
+
+        Returns a set of Firewall Policies which match the filter criteria.
 
         Keyword arguments:
         filter -- The filter expression that should be used to limit the results. FQL syntax.
@@ -184,8 +186,9 @@ class FirewallPolicies(ServiceClass):
 
     @force_default(defaults=["body"], default_types=["dict"])
     def set_policies(self: object, body: dict = None, **kwargs) -> dict:
-        """Sets the precedence of Firewall Policies based on the order of IDs specified in the
-        request. The first ID specified will have the highest precedence and the last ID specified
+        """Set the precedence of Firewall Policies based on the order of IDs specified in the request.
+
+        The first ID specified will have the highest precedence and the last ID specified
         will have the lowest. You must specify all non-Default Policies for a platform when
         updating precedence.
 
@@ -356,8 +359,9 @@ class FirewallPolicies(ServiceClass):
 
     @force_default(defaults=["parameters"], default_types=["dict"])
     def query_policy_members(self: object, parameters: dict = None, **kwargs) -> dict:
-        """Search for members of a Firewall Policy in your environment by providing an FQL filter
-        and paging details. Returns a set of Agent IDs which match the filter criteria.
+        """Search for members of a Firewall Policy in your environment by providing an FQL filter and paging details.
+
+        Returns a set of Agent IDs which match the filter criteria.
 
         Keyword arguments:
         id -- The ID of the Device Control Policy to search for members of
@@ -388,8 +392,9 @@ class FirewallPolicies(ServiceClass):
 
     @force_default(defaults=["parameters"], default_types=["dict"])
     def query_policies(self: object, parameters: dict = None, **kwargs) -> dict:
-        """Search for Firewall Policies in your environment by providing an FQL filter and paging
-        details. Returns a set of Firewall Policy IDs which match the filter criteria.
+        """Search for Firewall Policies in your environment by providing an FQL filter and paging details.
+
+        Returns a set of Firewall Policy IDs which match the filter criteria.
 
         Keyword arguments:
         filter -- The filter expression that should be used to limit the results. FQL syntax.
